@@ -11,9 +11,10 @@ module Foundation.List.DList
     ( DList
     ) where
 
-import Foundation.Internal.Base
+import Basement.Compat.Base
+import Basement.Compat.Semigroup
+import Basement.Compat.Bifunctor
 import Foundation.Collection
-import Foundation.Class.Bifunctor
 
 newtype DList a = DList { unDList :: [a] -> [a] }
   deriving (Typeable)
@@ -29,9 +30,11 @@ instance Show a => Show (DList a) where
 
 instance IsList (DList a) where
     type Item (DList a) = a
-    fromList = DList . (<>)
+    fromList = DList . (Basement.Compat.Semigroup.<>)
     toList = flip unDList []
 
+instance Semigroup (DList a) where
+    (<>) dl1 dl2 = DList $ unDList dl1 . unDList dl2
 instance Monoid (DList a) where
     mempty = DList id
     mappend dl1 dl2 = DList $ unDList dl1 . unDList dl2
@@ -70,10 +73,12 @@ instance Sequential (DList a) where
     splitAt n = bimap fromList fromList . splitAt n . toList
     splitOn f = fmap fromList . splitOn f . toList
     break f = bimap fromList fromList . break f . toList
+    breakEnd f = bimap fromList fromList . breakEnd f . toList
     breakElem e = bimap fromList fromList . breakElem e . toList
     intersperse e = fromList . intersperse e . toList
     intercalate e = intercalate e . toList
     span f = bimap fromList fromList . span f . toList
+    spanEnd f = bimap fromList fromList . spanEnd f . toList
     filter f = fromList . filter f . toList
     partition f = bimap fromList fromList . partition f . toList
     reverse = fromList . reverse . toList
