@@ -40,6 +40,10 @@ instance AMPMonad m => Monad (ReaderT r m) where
     ma >>= mab = ReaderT $ \r -> runReaderT ma r >>= \a -> runReaderT (mab a) r
     {-# INLINE (>>=) #-}
 
+instance (AMPMonad m, MonadFix m) => MonadFix (ReaderT s m) where
+    mfix f = ReaderT $ \r -> mfix $ \a -> runReaderT (f a) r
+    {-# INLINE mfix #-}
+
 instance MonadTrans (ReaderT r) where
     lift f = ReaderT $ const f
     {-# INLINE lift #-}
