@@ -1,8 +1,6 @@
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TemplateHaskell #-}
 module Test.Foundation.Misc
     ( testHexadecimal
-    , testTime
     , testUUID
     ) where
 
@@ -35,16 +33,6 @@ testHexadecimal = Group "hexadecimal"
         toList (toHexadecimal (fromListP (Proxy :: Proxy (UArray Word8)) l)) == hex l
     ]
 
-testTime = Group "Time"
-    [ Property "foundation_time_clock_gettime links properly" $
-        $(let s :: String
-              s = fromString "Hello"
-
-              b :: Bool
-              b = s == s
-           in [| b |])
-    ]
-
 testUUID = Group "UUID"
     [ Property "show" $ show UUID.nil === "00000000-0000-0000-0000-000000000000"
     , Property "show-bin" $ fmap show (UUID.fromBinary (fromList [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16])) === Just "100f0e0d-0c0b-0a09-0807-060504030201"
